@@ -1,8 +1,8 @@
 //! A standard erased box implementation, larger but simple implementation
 
 use alloc::boxed::Box;
-use core::mem;
 use core::ptr::{NonNull, Pointee};
+use core::{fmt, mem};
 
 #[inline]
 fn reify_ptr<T: ?Sized + Pointee>(data: NonNull<()>, meta: NonNull<()>) -> NonNull<T> {
@@ -111,6 +111,21 @@ impl ErasedBox {
     }
 }
 
+impl fmt::Pointer for ErasedBox {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt::Pointer::fmt(&self.data, f)
+    }
+}
+
+impl fmt::Debug for ErasedBox {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("ErasedBox")
+            .field("data", &self.data)
+            .field("meta", &self.meta)
+            .finish_non_exhaustive()
+    }
+}
+
 impl<T: ?Sized> From<Box<T>> for ErasedBox {
     fn from(b: Box<T>) -> Self {
         let val = NonNull::from(Box::leak(b));
